%bcond_with podman
%global import_path github.com/containers/buildah

Summary:       A command line tool used for creating OCI Images
Name:          buildah
Version:       1.34.1
Release:       1%{?dist}
License:       ASL 2.0
URL:           https://%{name}.io
Source0:       https://%{import_path}/archive/refs/tags/v%{version}.tar.gz

BuildRequires: make glib2-devel glibc-static git
BuildRequires: go-md2man golang >= 1.16.6 go-rpm-macros
BuildRequires: device-mapper-devel libassuan-devel
BuildRequires: gpgme-devel libassuan-devel ostree-devel
BuildRequires: libseccomp-devel
Requires:      containers-common-extra libseccomp

%description
The %{name} package provides a command line tool which can be used to
* create a working container from scratch
or
* create a working container from an image as a starting point
* mount/umount a working container's root file system for manipulation
* save container's root file system layer to create a new image
* delete a working container or an image


%package tests
Summary: Tests for %{name}

Requires: %{name} = %{version}-%{release}
Requires: bzip2 openssl
%if %{with podman}
Requires: podman
%endif
Requires: golang
Requires: jq httpd-tools nmap-ncat

%description tests
This package contains system tests for %{name}


%prep
%autosetup -Sgit -n %{name}-%{version}
sed -i 's/GOMD2MAN =/GOMD2MAN ?=/' docs/Makefile
sed -i '/docs install/d' Makefile


%build
mkdir _build
cd _build
mkdir -p src/github.com/containers
ln -s ../../../../ src/%{import_path}
cd ..

mv vendor src

export GOPATH=$(pwd)/_build:$(pwd)
export BUILDTAGS='seccomp selinux btrfs_noversion exclude_graphdriver_btrfs'
export GO111MODULE=off
export CGO_CFLAGS="%{optflags} -D_GNU_SOURCE -D_LARGEFILE_SOURCE -D_LARGEFILE64_SOURCE -D_FILE_OFFSET_BITS=64"
export CNI_VERSION=`grep '^# github.com/containernetworking/cni ' src/modules.txt | sed 's,.* ,,'`
export LDFLAGS="-X main.buildInfo=`date +%s` -X main.cniVersion=${CNI_VERSION}"
rm -f src/github.com/containers/storage/drivers/register/register_btrfs.go

%gobuild -o bin/%{name} %{import_path}/cmd/%{name}
%gobuild -o imgtype %{import_path}/tests/imgtype
%gobuild -o bin/copy %{import_path}/tests/copy
%gobuild -o bin/tutorial %{import_path}/tests/tutorial
GOMD2MAN=go-md2man %{__make} -C docs


%install
export GOPATH=$(pwd)/_build:$(pwd)
make DESTDIR=%{buildroot} PREFIX=%{_prefix} install install.completions
make DESTDIR=%{buildroot} PREFIX=%{_prefix} -C docs install

install -d -p %{buildroot}/%{_datadir}/%{name}/test/system
cp -pav tests/. %{buildroot}/%{_datadir}/%{name}/test/system
cp imgtype %{buildroot}/%{_bindir}/%{name}-imgtype
cp bin/copy    %{buildroot}/%{_bindir}/%{name}-copy
cp bin/tutorial %{buildroot}/%{_bindir}/%{name}-tutorial


%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}


%files tests
%license LICENSE
%{_bindir}/%{name}-imgtype
%{_bindir}/%{name}-copy
%{_bindir}/%{name}-tutorial
%{_datadir}/%{name}/test


%changelog
* Wed Mar 06 2024 jackeyji <jackeyji@tencent.com> - 1.34.1-1
- Upgrade to version 1.34.1 to adapt moby/buildkit

* Fri Dec 29 2023 jackeyji <jackeyji@tencent.com> - 1.31.2-3
- Rebuilt for golang CVE-2023-39318 and CVE-2023-39319

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.31.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 22 2023 Wang Guodong <gordonwwang@tencent.com> - 1.31.2-1
- Upgrade to version 1.31.2

* Wed Jun 21 2023 kianli <kianli@tencent.com> - 1.30.0-1
- Upgrade to 1.30.0 and fix Source0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.29.1-5
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.29.1-4
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 30 2023 rockerzhu <rockerzhu@tencent.com> - 1.29.1-3
- Fix license.

* Thu Mar 30 2023 rockerzhu <rockerzhu@tencent.com> - 1.29.1-2
- Don't use gopath macro.

* Thu Mar 30 2023 rockerzhu <rockerzhu@tencent.com> - 1.29.1-1
- Initial build

